"""
Fleet Management System — Automotive Telematics Platform
Copyright 2026 Santosh Kumar. Licensed under Apache 2.0.
"""

__version__ = "1.0.0"
__author__ = "Santosh Kumar"
__license__ = "Apache-2.0"
